/*
 FileDelete.java - utility class to delete files and directories
 
 Copyright  (C) 2005 Hugues Johnson
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package com.huguesjohnson;

import java.io.File;

/**
 * FileDelete - utility class to delete files and directories
 * @author Hugues Johnson
 */
public abstract class FileDelete{
	/**
	 * Delete a file.
	 * @param filePath The file to delete.
	 * @return True if the operation is successful.
	 */
	public final static boolean deleteFile(String filePath){
		return((new File(filePath)).delete());
	}

	/**
	 * Recursively delete a directory.
	 * @param directoryPath The directory to delete.
	 * @return True if the operation is successful.
	 */
	public final static boolean deleteDirectory(String directoryPath){
		boolean success=true;
		File directory=new File(directoryPath);
		if(directory.isDirectory()){
			File[] fileList=directory.listFiles();
			int length=fileList.length;
			int index=0;
			while((success)&&(index<length)){
				if(fileList[index].isDirectory()){
					success=deleteDirectory(fileList[index].getAbsolutePath());
				} else{
					success=deleteFile(fileList[index].getAbsolutePath());
				}
				index++;
			}
			success=directory.delete();
		} else{
			success=true;
		}
		return(success);
	}
}