/*
 ImageLoader.java - utility class to load an image from a file
 
 Copyright  (C) 2004-2005 Hugues Johnson
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package com.huguesjohnson;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import javax.imageio.ImageIO;

/**
 * Utility class to load an image from a file.
 * @author Hugues Johnson
 */
public abstract class ImageLoader{

	/**
	 * Loads a BufferedImage from a file.
	 * @param imagePath The full path to the file to load.
	 * @return A bufferedImage or null if an error occurs.
	 */
	public final static BufferedImage loadBufferedImage(String imagePath){
		try{
			BufferedImage image=null;
			if(imagePath!=null){
				File imageFile=new File(imagePath);
				if((imageFile.exists())&&(imageFile.isFile())){
					image=ImageIO.read(imageFile);
				}
			}
			return(image);
		} catch(IOException iox){
			iox.printStackTrace();
			return(null);
		}
	}
}